@@ -21,9 +21,9 @@ func TestRepoNameWithDifferentRemote(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
 	testlib.GitRemoteAddWithName(t, "upstream", "https://github.com/goreleaser/goreleaser.git")
-	_, err := git.Run("pull", "upstream", "master")
+	_, err := git.Run("pull", "upstream", "main")
 	require.NoError(t, err)
-	_, err = git.Run("branch", "--set-upstream-to", "upstream/master")
+	_, err = git.Run("branch", "--set-upstream-to", "upstream/main")
 	require.NoError(t, err)
 	repo, err := git.ExtractRepoFromConfig()
 	require.NoError(t, err)
