@@ -7,7 +7,6 @@ import (
 	"errors"
 	"fmt"
 	"os"
-	"strings"
 
 	"github.com/apex/log"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
@@ -45,16 +44,16 @@ func setDefaultTokenFiles(ctx *context.Context) {
 // Run the pipe.
 func (Pipe) Run(ctx *context.Context) error {
 	templ := tmpl.New(ctx).WithEnvS(os.Environ())
+	tEnv := []string{}
 	for i := range ctx.Config.Env {
 		env, err := templ.Apply(ctx.Config.Env[i])
 		if err != nil {
 			return err
 		}
-		// XXX: this has no risk of panicking because it would already have
-		// panicked at `context.go`'s `splitEnv` method.
-		// Need to properly handle this at some point.
-		parts := strings.SplitN(env, "=", 2)
-		ctx.Env[parts[0]] = parts[1]
+		tEnv = append(tEnv, env)
+	}
+	for k, v := range context.ToEnv(tEnv) {
+		ctx.Env[k] = v
 	}
 
 	setDefaultTokenFiles(ctx)
