@@ -122,6 +122,10 @@ func TestRunPipe(t *testing.T) {
 							Destination: "/etc/nope.conf",
 							Type:        "config",
 						},
+						{
+							Destination: "/etc/mydir",
+							Type:        "dir",
+						},
 						{
 							Source:      "./testdata/testfile.txt",
 							Destination: "/etc/nope-rpm.conf",
@@ -167,8 +171,8 @@ func TestRunPipe(t *testing.T) {
 	for _, pkg := range packages {
 		format := pkg.Format()
 		require.NotEmpty(t, format)
-		require.Equal(t, pkg.Name, "foo_1.0.0_Tux_"+pkg.Goarch+"-10-20."+format)
-		require.Equal(t, pkg.ID(), "someid")
+		require.Equal(t, "foo_1.0.0_Tux_"+pkg.Goarch+"-10-20."+format, pkg.Name)
+		require.Equal(t, "someid", pkg.ID())
 		require.ElementsMatch(t, []string{
 			"./testdata/testfile.txt",
 			"./testdata/testfile.txt",
@@ -179,6 +183,7 @@ func TestRunPipe(t *testing.T) {
 		}, sources(pkg.ExtraOr(extraFiles, files.Contents{}).(files.Contents)))
 		require.ElementsMatch(t, []string{
 			"/usr/share/testfile.txt",
+			"/etc/mydir",
 			"/etc/nope.conf",
 			"/etc/nope-rpm.conf",
 			"/etc/nope2.conf",
@@ -186,7 +191,75 @@ func TestRunPipe(t *testing.T) {
 			"/usr/bin/subdir/mybin",
 		}, destinations(pkg.ExtraOr(extraFiles, files.Contents{}).(files.Contents)))
 	}
-	require.Len(t, ctx.Config.NFPMs[0].Contents, 5, "should not modify the config file list")
+	require.Len(t, ctx.Config.NFPMs[0].Contents, 6, "should not modify the config file list")
+}
+
+func TestRunPipeConventionalNameTemplate(t *testing.T) {
+	folder := t.TempDir()
+	dist := filepath.Join(folder, "dist")
+	require.NoError(t, os.Mkdir(dist, 0o755))
+	require.NoError(t, os.Mkdir(filepath.Join(dist, "mybin"), 0o755))
+	binPath := filepath.Join(dist, "mybin", "mybin")
+	f, err := os.Create(binPath)
+	require.NoError(t, err)
+	require.NoError(t, f.Close())
+	ctx := context.New(config.Project{
+		ProjectName: "mybin",
+		Dist:        dist,
+		NFPMs: []config.NFPM{
+			{
+				ID:          "someid",
+				Builds:      []string{"default"},
+				Formats:     []string{"deb", "rpm", "apk"},
+				Section:     "somesection",
+				Priority:    "standard",
+				Description: "Some description ",
+				License:     "MIT",
+				Maintainer:  "me@me",
+				Vendor:      "asdf",
+				Homepage:    "https://goreleaser.com/",
+				Bindir:      "/usr/bin",
+				NFPMOverridables: config.NFPMOverridables{
+					FileNameTemplate: "{{ .ConventionalFileName }}",
+					PackageName:      "foo",
+				},
+			},
+		},
+	})
+	ctx.Version = "1.0.0"
+	ctx.Git = context.GitInfo{CurrentTag: "v1.0.0"}
+	for _, goos := range []string{"linux", "darwin"} {
+		for _, goarch := range []string{"amd64", "386"} {
+			ctx.Artifacts.Add(&artifact.Artifact{
+				Name:   "subdir/mybin",
+				Path:   binPath,
+				Goarch: goarch,
+				Goos:   goos,
+				Type:   artifact.Binary,
+				Extra: map[string]interface{}{
+					artifact.ExtraID: "default",
+				},
+			})
+		}
+	}
+	require.NoError(t, Pipe{}.Run(ctx))
+	packages := ctx.Artifacts.Filter(artifact.ByType(artifact.LinuxPackage)).List()
+	require.Len(t, packages, 6)
+	for _, pkg := range packages {
+		format := pkg.Format()
+		require.NotEmpty(t, format)
+		require.Contains(t, []string{
+			"foo_1.0.0_amd64.deb",
+			"foo_1.0.0_x86.apk",
+			"foo_1.0.0_i386.deb",
+			"foo_1.0.0_x86_64.apk",
+			"foo-1.0.0.i386.rpm",
+			"foo-1.0.0.x86_64.rpm",
+		}, pkg.Name, "package name is not expected")
+		require.Equal(t, "someid", pkg.ID())
+		require.ElementsMatch(t, []string{binPath}, sources(pkg.ExtraOr(extraFiles, files.Contents{}).(files.Contents)))
+		require.ElementsMatch(t, []string{"/usr/bin/subdir/mybin"}, destinations(pkg.ExtraOr(extraFiles, files.Contents{}).(files.Contents)))
+	}
 }
 
 func TestInvalidTemplate(t *testing.T) {
@@ -196,6 +269,7 @@ func TestInvalidTemplate(t *testing.T) {
 			Parallelism: runtime.NumCPU(),
 			Artifacts:   artifact.New(),
 			Config: config.Project{
+				ProjectName: "test",
 				NFPMs: []config.NFPM{
 					{
 						Formats: []string{"deb"},
@@ -218,9 +292,11 @@ func TestInvalidTemplate(t *testing.T) {
 
 	t.Run("filename_template", func(t *testing.T) {
 		ctx := makeCtx()
+		ctx.Config.NFPMs[0].Meta = true
 		ctx.Config.NFPMs[0].NFPMOverridables = config.NFPMOverridables{
 			FileNameTemplate: "{{.Foo}",
 		}
+		require.NoError(t, Pipe{}.Default(ctx))
 		require.Contains(t, Pipe{}.Run(ctx).Error(), `template: tmpl:1: unexpected "}" in operand`)
 	})
 
@@ -402,7 +478,7 @@ func TestInvalidConfig(t *testing.T) {
 		},
 	})
 	ctx.Git.CurrentTag = "v1.2.3"
-	ctx.Version = "v1.2.3"
+	ctx.Version = "1.2.3"
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "mybin",
 		Path:   filepath.Join(dist, "mybin", "mybin"),
@@ -1141,6 +1217,9 @@ func TestSkip(t *testing.T) {
 func sources(contents files.Contents) []string {
 	result := make([]string, 0, len(contents))
 	for _, f := range contents {
+		if f.Source == "" {
+			continue
+		}
 		result = append(result, f.Source)
 	}
 	return result
