@@ -101,34 +101,50 @@ func (Pipe) Run(ctx *context.Context) error {
 
 func sign(ctx *context.Context, cfg config.Sign, artifacts []*artifact.Artifact) error {
 	for _, a := range artifacts {
-		artifact, err := signone(ctx, cfg, a)
+		artifacts, err := signone(ctx, cfg, a)
 		if err != nil {
 			return err
 		}
-		if artifact != nil {
+		for _, artifact := range artifacts {
 			ctx.Artifacts.Add(artifact)
 		}
 	}
 	return nil
 }
 
-func signone(ctx *context.Context, cfg config.Sign, a *artifact.Artifact) (*artifact.Artifact, error) {
+func signone(ctx *context.Context, cfg config.Sign, art *artifact.Artifact) ([]*artifact.Artifact, error) {
 	env := ctx.Env.Copy()
-	env["artifact"] = a.Path
-	env["artifactID"] = a.ID()
+	env["artifactName"] = art.Name
+	env["artifact"] = art.Path
+	env["artifactID"] = art.ID()
+
+	tmplEnv, err := templateEnvS(ctx, cfg.Env)
+	if err != nil {
+		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
+	}
+
+	for k, v := range context.ToEnv(tmplEnv) {
+		env[k] = v
+	}
 
 	name, err := tmpl.New(ctx).WithEnv(env).Apply(expand(cfg.Signature, env))
 	if err != nil {
-		return nil, fmt.Errorf("sign failed: %s: invalid template: %w", a, err)
+		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
 	}
 	env["signature"] = name
 
+	cert, err := tmpl.New(ctx).WithEnv(env).Apply(expand(cfg.Certificate, env))
+	if err != nil {
+		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
+	}
+	env["certificate"] = cert
+
 	// nolint:prealloc
 	var args []string
 	for _, a := range cfg.Args {
 		arg, err := tmpl.New(ctx).WithEnv(env).Apply(expand(a, env))
 		if err != nil {
-			return nil, fmt.Errorf("sign failed: %s: invalid template: %w", a, err)
+			return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
 		}
 		args = append(args, arg)
 	}
@@ -150,7 +166,7 @@ func signone(ctx *context.Context, cfg config.Sign, a *artifact.Artifact) (*arti
 		stdin = f
 	}
 
-	fields := log.Fields{"cmd": cfg.Cmd, "artifact": a.Name}
+	fields := log.Fields{"cmd": cfg.Cmd, "artifact": art.Name}
 
 	// The GoASTScanner flags this as a security risk.
 	// However, this works as intended. The nosec annotation
@@ -164,6 +180,7 @@ func signone(ctx *context.Context, cfg config.Sign, a *artifact.Artifact) (*arti
 	if stdin != nil {
 		cmd.Stdin = stdin
 	}
+	cmd.Env = env.Strings()
 	log.WithFields(fields).Info("signing")
 	if err := cmd.Run(); err != nil {
 		return nil, fmt.Errorf("sign: %s failed: %w: %s", cfg.Cmd, err, b.String())
@@ -173,22 +190,37 @@ func signone(ctx *context.Context, cfg config.Sign, a *artifact.Artifact) (*arti
 		return nil, nil
 	}
 
-	env["artifact"] = a.Name
+	env["artifact"] = art.Name
 	name, err = tmpl.New(ctx).WithEnv(env).Apply(expand(cfg.Signature, env))
 	if err != nil {
-		return nil, fmt.Errorf("sign failed: %s: invalid template: %w", a, err)
+		return nil, fmt.Errorf("sign failed: %s: invalid template: %w", art.Name, err)
 	}
 
-	artifactPathBase, _ := filepath.Split(a.Path)
+	artifactPathBase, _ := filepath.Split(art.Path)
 	sigFilename := filepath.Base(env["signature"])
-	return &artifact.Artifact{
-		Type: artifact.Signature,
-		Name: name,
-		Path: filepath.Join(artifactPathBase, sigFilename),
-		Extra: map[string]interface{}{
-			artifact.ExtraID: cfg.ID,
+	result := []*artifact.Artifact{
+		{
+			Type: artifact.Signature,
+			Name: name,
+			Path: filepath.Join(artifactPathBase, sigFilename),
+			Extra: map[string]interface{}{
+				artifact.ExtraID: cfg.ID,
+			},
 		},
-	}, nil
+	}
+
+	if cert != "" {
+		result = append(result, &artifact.Artifact{
+			Type: artifact.Certificate,
+			Name: cert,
+			Path: filepath.Join(artifactPathBase, cert),
+			Extra: map[string]interface{}{
+				artifact.ExtraID: cfg.ID,
+			},
+		})
+	}
+
+	return result, nil
 }
 
 func expand(s string, env map[string]string) string {
@@ -196,3 +228,15 @@ func expand(s string, env map[string]string) string {
 		return env[key]
 	})
 }
+
+func templateEnvS(ctx *context.Context, s []string) ([]string, error) {
+	var out []string
+	for _, s := range s {
+		ts, err := tmpl.New(ctx).WithEnvS(out).Apply(s)
+		if err != nil {
+			return nil, err
+		}
+		out = append(out, ts)
+	}
+	return out, nil
+}
