@@ -155,6 +155,8 @@ func TestFuncMap(t *testing.T) {
 	wd, err := os.Getwd()
 	require.NoError(t, err)
 
+	ctx.Git.URL = "https://github.com/foo/bar.git"
+	ctx.ReleaseURL = "https://github.com/foo/bar/releases/tag/v1.0.0"
 	ctx.Git.CurrentTag = "v1.2.4"
 	for _, tc := range []struct {
 		Template string
@@ -198,6 +200,16 @@ func TestFuncMap(t *testing.T) {
 			Name:     "trimprefix",
 			Expected: "1.2.4",
 		},
+		{
+			Template: `{{ trimsuffix .GitURL ".git" }}`,
+			Name:     "trimsuffix",
+			Expected: "https://github.com/foo/bar",
+		},
+		{
+			Template: `{{ .ReleaseURL }}`,
+			Name:     "trimsuffix",
+			Expected: "https://github.com/foo/bar/releases/tag/v1.0.0",
+		},
 		{
 			Template: `{{ toupper "test" }}`,
 			Name:     "toupper",
